@@ -21,7 +21,7 @@ import (
 )
 
 const (
-	version = "0.3.7"
+	version = "0.3.8"
 )
 
 // Created with https://github.com/miku/zek
@@ -229,7 +229,7 @@ func checkRecord(records []xmppsrv.SRV, verbose bool, ipv4 bool, ipv6 bool, test
 			fmt.Println()
 		}
 		printRecord(record)
-		if verbose {
+		if verbose && record.Target != "." {
 			printIP(record, ipv4, ipv6, test, tlsConfig, timeout)
 		}
 	}
